# System import
import os, secrets
from datetime import timedelta


# Lib imports


# Apoplication imports


# Configs
APP_NAME      = 'Dropper'


class Config(object):
    TITLE      = APP_NAME
    DEBUG      = False
    TESTING    = False
    THREADED   = True
    SECRET_KEY = secrets.token_hex(32)

    HOME_PTH      = os.path.expanduser("~")
    ROOT_FILE_PTH = os.path.dirname(os.path.realpath(__file__))

    PERMANENT_SESSION_LIFETIME     = timedelta(days = 7).total_seconds()
    SQLALCHEMY_DATABASE_URI        = "sqlite:///static/db/webfm.db"
    SQLALCHEMY_TRACK_MODIFICATIONS = False

    OIDC_TOKEN_TYPE_HINT           = 'access_token'
    APP_REDIRECT_URI               = "https%3A%2F%2Fwww.dropper.com%2F"  # This path is submitted as the redirect URI in certain code flows
    OIDC_CLIENT_SECRETS            = ROOT_FILE_PTH + '/client_secrets.json'
    OIDC_ID_TOKEN_COOKIE_SECURE    = True
    OIDC_REQUIRE_VERIFIED_EMAIL    = False
    OIDC_USER_INFO_ENABLED         = True
    OIDC_VALID_ISSUERS   = [
                            'http://www.ssoapps.com/auth/realms/apps',
                            'https://www.ssoapps.com/auth/realms/apps'
                        ]


class ProductionConfig(Config):
    pass


class DevelopmentConfig(Config):
    DEBUG        = True
    USE_RELOADER = True
    OIDC_ID_TOKEN_COOKIE_SECURE = False
    OIDC_REQUIRE_VERIFIED_EMAIL = False


class TestingConfig(Config):
    TESTING = True
